var assert = require('assert'),
    suite = require('testingey').createSuite('indexer'),
    indexer = require('../lib/indexer'),
    indices = null,
    users = null;

suite.setUp(function () {
  
  users = [
    { username: 'jaydee', country: 'PH', age: 32, type: 0 },
    { username: 'sheryl', country: 'PH', age: 33, type: 0 },
    { username: 'juliane', country: 'PH', age: 0, type: 1 }
  ];
  
  indices = {
    username: indexer.create('username'),
    country: indexer.create('country'),
    age: indexer.create({ name: 'age', type: 'numeric' }),
    type: indexer.create({ name: 'type', type: 'numeric' })
  };

});

suite.spec('Testing index.add()', function () {
  users.forEach(function (user) {
    indices['username'].add(user.username, user.username);
    assert.equal(indices['username'].search(user.username).length, 1);
  });
});

suite.spec('Testing index.all()', function () {
  var matches = indices['username'].all(2, 1);
  assert.equal(matches.length, 2);
});

suite.spec('Testing index.remove()', function () {
  users.forEach(function (user) {
    indices['username'].remove(user.username);
    assert.equal(indices['username'].search(user.username).length, 0);
  });
});

suite.spec('Testing index.search()', function () {
  
  users.forEach(function (user) {
    indices['type'].add(user.type, user.username);
  });
  
  var matches = indices['type'].search(1);
  assert.equal(matches.length, 1);
  assert.equal(matches[0], 'juliane');

  indices['type'].remove('juliane');

  matches = indices['type'].search(1);
  assert.equal(matches.length, 0);
});

suite.run();
